"{ Package: 'jv:libgdbs/tests' }"

"{ NameSpace: Smalltalk }"

GDBDebuggerTestCase subclass:#GDBDebuggerTestsS
	instanceVariableNames:'simulator'
	classVariableNames:'DefaultWaitForTimeout'
	poolDictionaries:''
	category:'GDB-Core-Tests'
!

!GDBDebuggerTestsS class methodsFor:'documentation'!

documentation
"
    Tests for GDBDebugger (using simulator)

    [author:]
        Jan Vrany <jan.vrany@fit.cvut.cz>

    [instance variables:]

    [class variables:]

    [see also:]

"
! !

!GDBDebuggerTestsS class methodsFor:'initialization'!

initialize
    "Invoked at system start or when the class is dynamically loaded."

    "/ please change as required (and remove this comment)

    DefaultWaitForTimeout := 100.

    "Modified: / 27-02-2015 / 11:43:41 / Jan Vrany <jan.vrany@fit.cvut.cz>"
! !

!GDBDebuggerTestsS methodsFor:'running'!

tearDown
    simulator notNil ifTrue:[ simulator stop ].
    debugger notNil ifTrue:[ debugger release ].

    "Created: / 06-09-2014 / 02:17:56 / Jan Vrany <jan.vrany@fit.cvut.cz>"
! !

!GDBDebuggerTestsS methodsFor:'tests - basic'!

test_basic_02
    simulator := GDBSimulatorProcess new record: GDBSimulatorResource session_factorial_01.
    simulator start.
    debugger := GDBDebugger newWithProcess: simulator.

    "Created: / 24-06-2014 / 09:09:17 / Jan Vrany <jan.vrany@fit.cvut.cz>"
    "Modified: / 06-09-2014 / 02:18:33 / Jan Vrany <jan.vrany@fit.cvut.cz>"
! !

!GDBDebuggerTestsS methodsFor:'tests - threads'!

test_inferiors_01a
    | tgevent tevent blocker |

    blocker := Semaphore new.
    simulator := GDBSimulatorProcess new record: GDBSimulatorResource session_factorial_01.
    simulator start.
    debugger := GDBDebugger newWithProcess: simulator.
    debugger announcer when: GDBThreadGroupEvent do:[:ev |  
        tgevent := ev.
    ].
    debugger announcer when: GDBThreadEvent do:[:ev |  
        tevent := ev.
    ].
    debugger send: (GDBMI_file_exec_and_symbols new arguments: {'/home/jv/Private/Projects/SmalltalkX/sources/branches/jv1/build/jv/libgdbs/tests/c/factorial'}).
    debugger send: (GDBCLICommand new value: 'b factorial').

    self assert: debugger inferiors size == 1.
    self assert: debugger inferiors anElement id = 'i1'.
    "/ No, following won't work as thread-group-added event is
    "/ emited before we register the handler above!!
    "/ self assert: debugger inferiors anElement == event threadGroup.

    self 
        do:[ debugger send: (GDBCLICommand new value: 'r') ]
        thenWaitFor: GDBStoppedEvent.

    self assert: tgevent notNil.
    self assert: tevent notNil.
    self assert: debugger inferiors size == 1.
    self assert: debugger inferiors anElement pid = 7719.
    self assert: debugger inferiors anElement == tgevent threadGroup.
    self assert: debugger inferiors anElement threads size == 1.
    self assert: debugger inferiors anElement threads anElement == tevent thread.
    self assert: debugger inferiors anElement threads anElement isTerminated not.
    self assert: debugger inferiors anElement threads anElement isRunning not.
    self assert: debugger inferiors anElement threads anElement isStopped.
    self assert: debugger inferiors anElement threads anElement stack size == 2. 

    tgevent := tevent := nil.

    debugger send: (GDBCLICommand new value: 'del 1').
    tgevent := self 
        do:[ debugger send: (GDBCLICommand new value: 'c') ]
        thenWaitFor: GDBThreadGroupExitedEvent.

    self assert: tgevent notNil.
    self assert: debugger inferiors size == 1.
    self assert: debugger inferiors anElement exitCode = 23.
    self assert: debugger inferiors anElement == tgevent threadGroup.
    "/ When thread group exits, all it's threads are dead so
    "/ inferior threads should return an empty collection.
    self assert: debugger inferiors anElement threads isEmptyOrNil.

    "Created: / 07-09-2014 / 13:37:11 / Jan Vrany <jan.vrany@fit.cvut.cz>"
    "Modified: / 27-02-2015 / 12:42:56 / Jan Vrany <jan.vrany@fit.cvut.cz>"
! !

!GDBDebuggerTestsS class methodsFor:'documentation'!

version_HG

    ^ '$Changeset: <not expanded> $'
! !


GDBDebuggerTestsS initialize!
